@@ -23,16 +23,17 @@ mod filter;
 mod logger;
 mod note;
 mod process_ext;
+mod settings;
 #[cfg(feature = "viewer")]
 mod viewer;
 mod workflow;
 
 extern crate semver;
 use crate::config::backup_config_file;
-use crate::config::ARGS;
 use crate::config::CFG;
 use crate::config::CFG_FILE_LOADING;
 use crate::logger::AppLogger;
+use crate::settings::ARGS;
 use crate::workflow::run;
 use error::FileError;
 use semver::Version;
@@ -62,7 +63,7 @@ const VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
 ///    const MIN_CONFIG_FILE_VERSION: Option<&'static str> = None;
 ///    ```
 ///
-const MIN_CONFIG_FILE_VERSION: Option<&'static str> = Some("1.13.0");
+const MIN_CONFIG_FILE_VERSION: Option<&'static str> = Some("1.13.3");
 /// (c) Jens Getreu
 const AUTHOR: &str = "(c) Jens Getreu, 2020-2021";
 
@@ -78,12 +79,12 @@ fn main() {
 
     // Set the debug level. Only use config file value if
     // no command-line-option `--debug` is present.
-    let level = ARGS.debug.unwrap_or(CFG.debug_arg_default);
+    let level = ARGS.debug.unwrap_or(CFG.arg_default.debug);
     AppLogger::set_max_level(level);
 
     // This eventually will extend the error reporting with more
     // popup alert windows.
-    AppLogger::set_popup_always_enabled(ARGS.popup || CFG.popup_arg_default);
+    AppLogger::set_popup_always_enabled(ARGS.popup || CFG.arg_default.popup);
 
     // Check if the config file loading was successful.
     let cfg_file_loading = &*CFG_FILE_LOADING.read().unwrap();
